{% extends 'layout.html' %} {% set crumbs = (('Miscellany',), ('Changelog',)) %} {% set toc = ( ('v0.3',), ('v0.2.3',), ('v0.2.2',), ('v0.2.1',), ('v0.2',), ('v0.1.9',), ('v0.1.8',), ('v0.1.7',), ('v0.1.6',), ('v0.1.5',), ('v0.1.4',), ('v0.1.3',), ('v0.1.2',), ('v0.1.1',), ('v0.1',) ) %} {% block content %}

This page is a comprehensive list of all user-visible changes between versions. If you are upgrading be sure to check out the upgrading page for any backwards incompatible changes.

# v0.3 (July 27th, 2014)

- New
  - A mechanism for defining content containers.
  - Two new filters for the Jinja renderer, `items` and `values`, that act as syntactic sugar for `iteritems()` and `itervalues()`.
  - A reStructuredText parser.
  - Two new `item` properties, `prev` and `next`, that store the previous and next items in the container.
  - Files outside of ignored directories will now be parsed if a parser is available.
  - Two config settings for controlling how posts are sorted: `posts_order` and `posts_sort`.
- Changed
  - Global and local dictionaries no longer behave different from ordinary Python dictionaries when iterating over them.
  - The `archives` and `tags` globals are now properties of the `posts` global to maintain consistency between content containers.
  - The `post` local has been renamed `item` to maintain consistency between content containers.
  - The `<title>` variable in URL formats has been renamed to `<slug>`.
  - Frontmatter attributes that contain string values can now be used in URL formats.
  - The `markup` and `parser` config settings have been removed.
  - Which parser used is now determined by (in order of precedence) the `parser` frontmatter attribute, the `parser` container config setting, and lastly the file extension.
  - In Markdown, the bracket fenced code block syntax is no longer supported.
  - The `layout` frontmatter attribute can now be set to `None` to skip rendering.

# v0.2.3 (June 13th, 2013)

- New
  - A new default theme with dark (default) and light versions.
  - A config setting for specifying directories and files to be copied over that would otherwise be ignored.
  - Localization and internationalization support.
- Changed
  - HTML escaping is now handled by Houdini.
  - The programming language of a code block is now stored in the `data-lang` attribute of the `<code>` tag instead of the `lang` attribute of the `<pre>` tag.
  - Tildes are no longer allowed in post slugs.
  - The `watch` subcommand now honors the configured log level.
- Upgraded
  - Jinja 2.7
- Fixed
  - A bug in the handling of log messages in the `serve` subcommand.
  - A bug in the misaka parser with SmartyPants.
  - A bug in the `serve` subcommand when handling paths containing Unicode characters.
  - A bug in the `watch` subcommand when a file is moved into the directory that is being watched.
  - A bug when handling an empty config file.

# v0.2.2 (April 11th, 2012)

- Upgraded
  - misaka 1.0.2
- Fixed
  - A bug in the `absolutize` filter of the Jinja renderer.
  - A bug in the `get_url` template helper where it was appending a forward slash when it shouldn't.

# v0.2.1 (March 20th, 2012)

- Fixed
  - The default theme not getting installed.

# v0.2 (March 20th, 2012)

- New
  - An archive property is now available for tags in the tags global.
  - A default theme.
  - Four new subcommands: `init`, `gen`, `watch`, and `serve`.
- Changed
  - Archive years and tag names are always available in their respective globals.
  - When the destination already exists on generation, it is now emptied by default instead of deleted.
  - Generation is now done via the `gen` subcommand.
- Fixed
  - A bug when retrieving the URL for an archive page.
  - A regression in the misaka renderer when generating semantic identifiers.

# v0.1.9 (March 12th, 2012)

- New
  - An absolute URL can now be retrieved via the `get_url` template helper if the `domain` config setting has been set.
  - A filter for the Jinja render that attempts to convert all relative URLs to absolute URLs.
- Changed
  - The misaka parser now automatically escapes code blocks.
- Fixed
  - A Unicode issue in the misaka parser.
  - An escaping issue with code highlighting.
  - A bug in the Jinja renderer when handling Windows paths.

# v0.1.8 (February 8th, 2012)

- Upgraded
  - miaska 1.0

# v0.1.7 (January 30th, 2012)

- Changed
  - The `excerpt` post property is no longer wrapped in a `<p>` tag.
- Fixed
  - A bug in the misaka parser when the Markdown source parses out to nothing.

# v0.1.6 (January 25th, 2012)

- Fixed
  - An import issue preventing installation.

# v0.1.5 (January 25th, 2012)

- Fixed
  - An import issue preventing installation.

# v0.1.4 (January 2nd, 2012)

- Fixed
  - A type issue in `setup.py`.

# v0.1.3 (January 2nd, 2012)

- New
  - A version flag.
- Changed
  - Removed the `year` and `name` properties from archives and tags respectively.

# v0.1.2 (December 27th, 2011)

- New
  - Posts are now partially rendered before being parsed enabling renderer functionality within posts.
  - The hour and minute of a post can now be set with it defaulting to the file's `mtime`.
  - Archive pages can now be automatically generated.
- Changed
  - Identifiers will now be semantic when using misaka's TOC render flag.
  - Removed the `slug` property from posts.
- Fixed
  - A bug when parsing posts with no content.
  - Post and tag URLs not being properly slugified.
  - A Unicode issue with dates.

# v0.1.1 (December 4th, 2011)

- Changed
  - Added a `name` attribute to tags.
- Fixed
  - A bug with extensionless files.
  - A bug when using the `-qv` flags.

# v0.1 (December 4th, 2011)

Initial release.

{% endblock %}